@@ -625,13 +625,12 @@ class EcogClient(object):
                                 if fromfiledate: options['fromfiledate'] = fromfiledate
                                 if tofiledate:   options['tofiledate']   = tofiledate
 
-                                diff = difflib.unified_diff(a_str.splitlines(True),b_str.splitlines(True), **options)
-                                return diff
+                                return difflib.unified_diff(a_str.splitlines(True),b_str.splitlines(True), **options)
 
                             # display diff lines
-                            fromfile,fromfiledate = '%s (rev %d)' % (title, revision), updated_at.strftime("%Y/%m/%d %H-%M")
-                            for line in diff_lines(rawbody,content, fromfile=fromfile, tofile='EDIT', 
-                                    fromfiledate=updated_at.strftime("%Y/%m/%d %H-%M")):
+                            fromfile     = '%s (rev %d)' % (title, revision)
+                            fromfiledate = updated_at.strftime("%Y/%m/%d %H-%M") if updated_at else None
+                            for line in diff_lines(rawbody,content, fromfile=fromfile,tofile='EDIT',fromfiledate=fromfiledate):
                                 output(line, end='')
                             comment = raw_input('comment message (default: %s): ' % self.ecog.DEFAULT_COMMENT)
                             comment = comment or self.ecog.DEFAULT_COMMENT
